==> abasic_0_0_4_2.zip: abasic_0_0_4_2/st_inst.h <==
/*
 * aBasic
 * Copyright (C) 2007 m_inaba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#if !defined(__ST_INST_)
#define __ST_INST_

#include "common.h"
#include "calc.h"
#include "variant.h"
#include "variant_io.h"
#include "vari.h"

int eval_(char*str);
int if_(char*str,unsigned char*flag);
int if2_(char*str,std::vector<std::string>*source,
		  unsigned int*p_counter,std::vector<unsigned long>*data,unsigned char*flag);
int else_(char*str,std::vector<std::string>*source,
		  unsigned int*p_counter,std::vector<unsigned long>*data,unsigned char*flag);
int print_(char*str,unsigned char*flag);
int input_(char*str,unsigned char*flag);
int goto_(char*str,std::vector<std::string>*source,unsigned int*p_counter,
		  std::vector<unsigned long>*data,unsigned char*flag);
int for_(char*str,unsigned char*flag);
int next_(char*str,
		  std::vector<std::string>*source,unsigned int*p_counter,
		  std::vector<unsigned long>*data,unsigned char*flag);
int clr_(char*str,unsigned char*flag);
int location_(char*str,unsigned char*flag);
int wait_(char*str,unsigned char*flag);
int gosub_(char*str,std::vector<std::string>*source,
		  unsigned int*p_counter,std::vector<unsigned long>*data,unsigned char*flag);
int return_(char*str,unsigned int*p_counter,unsigned char*flag);
int abs_(char*str,unsigned char*flag);
int shell_(char*str,unsigned char*flag);

int len_(char*str,unsigned char*flag);
int mid_(char*str,unsigned char*flag);
int val_(char*str,unsigned char*flag);
int str_(char*str,unsigned char*flag);
int csv_(char*str,unsigned char*flag);
int vsc_(char*str,unsigned char*flag);
int chop_(char*str,unsigned char*flag);
int trim_(char*str,unsigned char*flag);
int ltrim_(char*str,unsigned char*flag);
int rtrim_(char*str,unsigned char*flag);
int replace_(char*str,unsigned char*flag);
int match_(char*str,unsigned char*flag);
int lcase_(char*str,unsigned char*flag);
int ucase_(char*str,unsigned char*flag);
int left_(char*str,unsigned char*flag);
int right_(char*str,unsigned char*flag);
int jis_(char*str,unsigned char*flag);
int asc_(char*str,unsigned char*flag);
int instr_(char*str,unsigned char*flag);
int fread_(char*str,unsigned char*flag);
int fwrite_(char*str,unsigned char*flag);

#endif

//-------------------------------------------------------------------------------

==> abasic_0_0_4_3.zip: abasic_0_0_4_3/st_inst.h <==
/*
 * aBasic
 * Copyright (C) 2007 m_inaba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#if !defined(__ST_INST_)
#define __ST_INST_

#include "common.h"
#include "calc.h"
#include "variant.h"
#include "variant_io.h"
#include "vari.h"

int eval_(char*str);
int if_(char*str,unsigned char*flag);
int if2_(char*str,std::vector<std::string>*source,
		  unsigned int*p_counter,std::vector<unsigned long>*data,unsigned char*flag);
int else_(char*str,std::vector<std::string>*source,
		  unsigned int*p_counter,std::vector<unsigned long>*data,unsigned char*flag);
int print_(char*str,unsigned char*flag);
int input_(char*str,unsigned char*flag);
int goto_(char*str,unsigned int*p_counter,unsigned char*flag);
int for_(char*str,unsigned char*flag);
int next_(char*str,
		  std::vector<std::string>*source,unsigned int*p_counter,
		  std::vector<unsigned long>*data,unsigned char*flag);
int clr_(char*str,unsigned char*flag);
int location_(char*str,unsigned char*flag);
int wait_(char*str,unsigned char*flag);
int gosub_(char*str,std::vector<std::string>*source,unsigned int*p_counter,unsigned char*flag);
int return_(char*str,unsigned int*p_counter,unsigned char*flag);
int abs_(char*str,unsigned char*flag);
int shell_(char*str,unsigned char*flag);

int len_(char*str,unsigned char*flag);
int mid_(char*str,unsigned char*flag);
int val_(char*str,unsigned char*flag);
int str_(char*str,unsigned char*flag);
int csv_(char*str,unsigned char*flag);
int vsc_(char*str,unsigned char*flag);
int chop_(char*str,unsigned char*flag);
int trim_(char*str,unsigned char*flag);
int ltrim_(char*str,unsigned char*flag);
int rtrim_(char*str,unsigned char*flag);
int replace_(char*str,unsigned char*flag);
int match_(char*str,unsigned char*flag);
int lcase_(char*str,unsigned char*flag);
int ucase_(char*str,unsigned char*flag);
int left_(char*str,unsigned char*flag);
int right_(char*str,unsigned char*flag);
int jis_(char*str,unsigned char*flag);
int asc_(char*str,unsigned char*flag);
int instr_(char*str,unsigned char*flag);
int fread_(char*str,unsigned char*flag);
int fwrite_(char*str,unsigned char*flag);
int block_(char*str,std::vector<std::string>*source,unsigned int*p_counter,
		  std::vector<unsigned long>*data,unsigned char*flag);
#endif

//-------------------------------------------------------------------------------
